@@ -45,6 +45,62 @@ def umap(model_results, color: Optional[str] = None, plot_type: Optional[str] =
         sc.pl.umap(adata, color='color' if color else None, **kwargs)
 
 
+
+
+def draw_term_family(id):
+    import lib310
+    import graphviz
+
+    results = lib310.db.fetch(query="""SELECT
+      pathList
+    FROM
+      `pfsdb3.1_go.term_term_path`
+    WHERE
+      child_id = {id}
+    """.format(id=id))
+    import graphviz
+    from collections import defaultdict
+
+    relationtype = {
+        'is_a': {'color': 'black', 'style': 'solid'},
+        'part_of': {'color': 'blue', 'style': 'dashed'},
+        'regulates': {'color': 'darkorange', 'style': 'bold'},
+        'positively_regulates': {'color': 'chartreuse1', 'style': 'bold'},
+        'negatively_regulates': {'color': 'red', 'style': 'bold'},
+        'occurs_in': {'color': 'darkslategray4', 'style': 'bold'},
+    }
+
+    defultrel = {'color': 'gray', 'style': 'dotted'}
+
+    u = graphviz.Digraph('unix', filename='unix.gv')
+    u.attr(size='100,100')
+    u.attr('node', shape='record')
+
+    edgeList = defaultdict(set)
+    rel = defaultdict(dict)
+    data = results[['pathList']].values.tolist()
+    for row in data:
+        paths = row
+        pathList = paths[0].strip('][').split(', ')
+        x = 0
+        while (x + 2 < len(pathList)):
+            edgeList[pathList[x]].add(pathList[x + 2])
+            rel[pathList[x]][pathList[x + 2]] = pathList[x + 1]
+            x = x + 2
+    for x in edgeList:
+        for y in edgeList[x]:
+            z = rel[x][y].replace(' " ', " ")
+            z = z.strip(' " " ')
+            z = z.replace("'", '')
+            if z in relationtype.keys():
+                u.edge(x[4:11], y[4:11], color=relationtype[z]['color'], style=relationtype[z]['style'])
+            else:
+                z = defultrel
+                u.edge(x[4:11], y[4:11], color=z['color'], style=z['style'])
+    u.view()
+    u
+
+
 def show_umap(features):
     from umap import UMAP
     import plotly.express as px
